@@ -20,15 +20,15 @@ stmar22c <- GSMAR(data=simudata, p=2, M=2, params=params22c, model="StMAR", cons
 gmar32cr <- GSMAR(data=simudata, p=3, M=2, params=params32cr, model="GMAR", restricted=TRUE, constraints=R1)
 gstmar12 <- GSMAR(data=simudata, p=1, M=c(1, 1), params=params12gs, model="G-StMAR")
 
-set.seed(1); pred12_0 <- predict.gsmar(gmar12, n_ahead=1, nsimu=1, pi_type="none", plotRes=FALSE, pred_type="mean")
-set.seed(1); pred12 <- predict.gsmar(gmar12, n_ahead=1, nsimu=50, pi=c(0.90, 0.80), plotRes=FALSE, pred_type="mean")
-set.seed(2); pred23_0 <- predict.gsmar(gmar23, n_ahead=1, nsimu=1, plotRes=FALSE, pred_type="cond_mean")
-set.seed(2); pred23 <- predict.gsmar(gmar23, n_ahead=3, nsimu=50, pi=c(0.99, 0.90, 0.60), plotRes=FALSE, pred_type="median")
-set.seed(3); pred12r <- predict.gsmar(gmar12r, n_ahead=3, nsimu=50, pi=c(0.999, 0.001), plotRes=FALSE, pred_type="median")
-set.seed(4); pred23r <- predict.gsmar(gmar23r, n_ahead=1, nsimu=50, pi=c(0.5), plotRes=FALSE, pred_type="mean")
-set.seed(5); pred22c <- predict.gsmar(stmar22c, n_ahead=1, nsimu=20, pi=c(0.99, 0.90, 0.60), plotRes=FALSE, pred_type="median")
-set.seed(6); pred32cr <- predict.gsmar(gmar32cr, n_ahead=1, nsimu=10, pi=c(0.90), plotRes=FALSE, pred_type="mean")
-set.seed(7); pred12gs <- predict.gsmar(gstmar12, n_ahead=1, nsimu=50, pi=c(0.90, 0.80), plotRes=FALSE, pred_type="mean")
+set.seed(1); pred12_0 <- predict.gsmar(gmar12, n_ahead=1, nsimu=1, pi_type="none", plot_res=FALSE, pred_type="mean")
+set.seed(1); pred12 <- predict.gsmar(gmar12, n_ahead=1, nsimu=50, pi=c(0.90, 0.80), plot_res=FALSE, pred_type="mean")
+set.seed(2); pred23_0 <- predict.gsmar(gmar23, n_ahead=1, nsimu=1, plot_res=FALSE, pred_type="cond_mean")
+set.seed(2); pred23 <- predict.gsmar(gmar23, n_ahead=3, nsimu=50, pi=c(0.99, 0.90, 0.60), plot_res=FALSE, pred_type="median")
+set.seed(3); pred12r <- predict.gsmar(gmar12r, n_ahead=3, nsimu=50, pi=c(0.999, 0.001), plot_res=FALSE, pred_type="median")
+set.seed(4); pred23r <- predict.gsmar(gmar23r, n_ahead=1, nsimu=50, pi=c(0.5), plot_res=FALSE, pred_type="mean")
+set.seed(5); pred22c <- predict.gsmar(stmar22c, n_ahead=1, nsimu=20, pi=c(0.99, 0.90, 0.60), plot_res=FALSE, pred_type="median")
+set.seed(6); pred32cr <- predict.gsmar(gmar32cr, n_ahead=1, nsimu=10, pi=c(0.90), plot_res=FALSE, pred_type="mean")
+set.seed(7); pred12gs <- predict.gsmar(gstmar12, n_ahead=1, nsimu=50, pi=c(0.90, 0.80), plot_res=FALSE, pred_type="mean")
 
 test_that("predict.gsmar gives correct prediction", {
   expect_equal(pred12_0$pred, 14.52315, tolerance=1e-3)
@@ -68,8 +68,8 @@ params12gs <- c(3.98, 0.68, 0.36, 0.70, 0.94, 11.75, 0.25, 2.03) # M = c(1, 1)
 params23gs <- c(2.0, 0.83, 0.01, 0.36, 1.14, 0.90, 0.01, 0.06, 4.23, 0.72, 0.01, 3.85, 0.6, 0.20, 3.3) # M = c(2, 1)
 gstmar12 <- GSMAR(simudata, p=1, M=c(1, 1), params=params12gs, model="G-StMAR")
 gstmar23 <- GSMAR(simudata, p=2, M=c(2, 1), params=params23gs, model="G-StMAR")
-pred12gs <- predict.gsmar(gstmar12, pred_type="cond_mean", plotRes=FALSE)
-pred23gs <- predict.gsmar(gstmar23, pred_type="cond_mean", plotRes=FALSE)
+pred12gs <- predict.gsmar(gstmar12, pred_type="cond_mean", plot_res=FALSE)
+pred23gs <- predict.gsmar(gstmar23, pred_type="cond_mean", plot_res=FALSE)
 
 test_that("predict.gsmar one-step-cond-mean works correctly", {
   expect_equal(pred12gs$pred, 14.90026, tolerance=1e-3)
